summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/projectsettingsimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/projectsettingsimpl.cpp')
-rw-r--r--kdevdesigner/designer/projectsettingsimpl.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdevdesigner/designer/projectsettingsimpl.cpp b/kdevdesigner/designer/projectsettingsimpl.cpp
index b616930d..5cea9192 100644
--- a/kdevdesigner/designer/projectsettingsimpl.cpp
+++ b/kdevdesigner/designer/projectsettingsimpl.cpp
@@ -48,14 +48,14 @@
#include <tqlabel.h>
/*
* Constructs a ProjectSettings which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-ProjectSettings::ProjectSettings( Project *pro, TQWidget* tqparent, const char* name, bool modal, WFlags fl )
- : ProjectSettingsBase( tqparent, name, modal, fl ), project( pro )
+ProjectSettings::ProjectSettings( Project *pro, TQWidget* parent, const char* name, bool modal, WFlags fl )
+ : ProjectSettingsBase( parent, name, modal, fl ), project( pro )
{
connect( buttonHelp, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
@@ -48,14 +48,14 @@
#include <tqlabel.h>
/*
- * Constructs a ProjectSettings which is a child of 'tqparent', with the
+ * Constructs a ProjectSettings which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*